summaryrefslogtreecommitdiff
path: root/chromecast
diff options
context:
space:
mode:
authorTorne (Richard Coles) <torne@google.com>2014-08-12 13:47:38 +0100
committerTorne (Richard Coles) <torne@google.com>2014-08-12 13:47:38 +0100
commit5f1c94371a64b3196d4be9466099bb892df9b88e (patch)
tree60a287ed27d1328d7806d12433d789b66ad91805 /chromecast
parent43165a58c6167882aabb62f470c4e4d21f807d79 (diff)
downloadchromium_org-5f1c94371a64b3196d4be9466099bb892df9b88e.tar.gz
Merge from Chromium at DEPS revision 288042
This commit was generated by merge_to_master.py. Change-Id: I583602ff16d735199f1810565c9296e970ce2854
Diffstat (limited to 'chromecast')
-rw-r--r--chromecast/chromecast.gyp36
-rw-r--r--chromecast/common/version.h.in12
-rw-r--r--chromecast/shell/browser/cast_content_browser_client.cc2
-rw-r--r--chromecast/shell/browser/cast_content_browser_client.h2
-rw-r--r--chromecast/shell/browser/url_request_context_factory.cc22
-rw-r--r--chromecast/shell/browser/url_request_context_factory.h2
-rw-r--r--chromecast/shell/common/cast_content_client.cc7
7 files changed, 62 insertions, 21 deletions
diff --git a/chromecast/chromecast.gyp b/chromecast/chromecast.gyp
index 5bd856c0a9..cfdac1ce01 100644
--- a/chromecast/chromecast.gyp
+++ b/chromecast/chromecast.gyp
@@ -71,6 +71,7 @@
'../content/browser/devtools/devtools_resources.gyp:devtools_resources',
'../content/content_resources.gyp:content_resources',
'../net/net.gyp:net_resources',
+ '../third_party/WebKit/public/blink_resources.gyp:blink_resources',
'../ui/resources/ui_resources.gyp:ui_resources',
'../ui/strings/ui_strings.gyp:ui_strings',
'../webkit/webkit_resources.gyp:webkit_resources',
@@ -81,13 +82,13 @@
'action_name': 'repack_cast_shell_pack',
'variables': {
'pak_inputs': [
+ '<(SHARED_INTERMEDIATE_DIR)/blink/public/resources/blink_resources.pak',
'<(SHARED_INTERMEDIATE_DIR)/content/content_resources.pak',
'<(SHARED_INTERMEDIATE_DIR)/net/net_resources.pak',
'<(SHARED_INTERMEDIATE_DIR)/ui/resources/ui_resources_100_percent.pak',
'<(SHARED_INTERMEDIATE_DIR)/ui/resources/webui_resources.pak',
'<(SHARED_INTERMEDIATE_DIR)/ui/strings/app_locale_settings_en-US.pak',
'<(SHARED_INTERMEDIATE_DIR)/ui/strings/ui_strings_en-US.pak',
- '<(SHARED_INTERMEDIATE_DIR)/webkit/blink_resources.pak',
'<(SHARED_INTERMEDIATE_DIR)/webkit/devtools_resources.pak',
'<(SHARED_INTERMEDIATE_DIR)/webkit/webkit_resources_100_percent.pak',
'<(SHARED_INTERMEDIATE_DIR)/webkit/webkit_strings_en-US.pak',
@@ -105,6 +106,7 @@
'cast_common',
'cast_service',
'cast_shell_pak',
+ 'cast_version_header',
'../ui/aura/aura.gyp:aura_test_support',
'../content/content.gyp:content',
'../content/content.gyp:content_app_browser',
@@ -147,5 +149,37 @@
}],
],
},
+ {
+ 'target_name': 'cast_version_header',
+ 'type': 'none',
+ 'direct_dependent_settings': {
+ 'include_dirs': [
+ '<(SHARED_INTERMEDIATE_DIR)',
+ ],
+ },
+ 'actions': [
+ {
+ 'action_name': 'version_header',
+ 'message': 'Generating version header file: <@(_outputs)',
+ 'inputs': [
+ '<(version_path)',
+ 'common/version.h.in',
+ ],
+ 'outputs': [
+ '<(SHARED_INTERMEDIATE_DIR)/chromecast/common/version.h',
+ ],
+ 'action': [
+ 'python',
+ '<(version_py_path)',
+ '-e', 'VERSION_FULL="<(version_full)"',
+ 'common/version.h.in',
+ '<@(_outputs)',
+ ],
+ 'includes': [
+ '../build/util/version.gypi',
+ ],
+ },
+ ],
+ },
], # end of targets
}
diff --git a/chromecast/common/version.h.in b/chromecast/common/version.h.in
new file mode 100644
index 0000000000..38bc38b918
--- /dev/null
+++ b/chromecast/common/version.h.in
@@ -0,0 +1,12 @@
+// Copyright 2014 The Chromium Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style license that can be
+// found in the LICENSE file.
+
+// version.h is generated from version.h.in. Edit the source!
+
+#ifndef CHROMECAST_COMMON_VERSION_INFO_H_
+#define CHROMECAST_COMMON_VERSION_INFO_H_
+
+#define PRODUCT_VERSION "@VERSION_FULL@"
+
+#endif // CHROMECAST_COMMON_VERSION_INFO_H_
diff --git a/chromecast/shell/browser/cast_content_browser_client.cc b/chromecast/shell/browser/cast_content_browser_client.cc
index 68d83913ba..fc1dac87b7 100644
--- a/chromecast/shell/browser/cast_content_browser_client.cc
+++ b/chromecast/shell/browser/cast_content_browser_client.cc
@@ -106,7 +106,7 @@ void CastContentBrowserClient::AllowCertificateError(
int cert_error,
const net::SSLInfo& ssl_info,
const GURL& request_url,
- content::ResourceType::Type resource_type,
+ content::ResourceType resource_type,
bool overridable,
bool strict_enforcement,
const base::Callback<void(bool)>& callback,
diff --git a/chromecast/shell/browser/cast_content_browser_client.h b/chromecast/shell/browser/cast_content_browser_client.h
index 0bfe1976b6..8647cd2a5f 100644
--- a/chromecast/shell/browser/cast_content_browser_client.h
+++ b/chromecast/shell/browser/cast_content_browser_client.h
@@ -43,7 +43,7 @@ class CastContentBrowserClient: public content::ContentBrowserClient {
int cert_error,
const net::SSLInfo& ssl_info,
const GURL& request_url,
- content::ResourceType::Type resource_type,
+ content::ResourceType resource_type,
bool overridable,
bool strict_enforcement,
const base::Callback<void(bool)>& callback,
diff --git a/chromecast/shell/browser/url_request_context_factory.h b/chromecast/shell/browser/url_request_context_factory.h
index e094c0d9a9..03d062da42 100644
--- a/chromecast/shell/browser/url_request_context_factory.h
+++ b/chromecast/shell/browser/url_request_context_factory.h
@@ -79,7 +79,7 @@ class URLRequestContextFactory {
// instance of URLRequestContext only.
bool system_dependencies_initialized_;
scoped_ptr<net::HostResolver> host_resolver_;
- scoped_ptr<net::ServerBoundCertService> server_bound_cert_service_;
+ scoped_ptr<net::ChannelIDService> channel_id_service_;
scoped_ptr<net::CertVerifier> cert_verifier_;
scoped_refptr<net::SSLConfigService> ssl_config_service_;
scoped_ptr<net::TransportSecurityState> transport_security_state_;
diff --git a/chromecast/shell/common/cast_content_client.cc b/chromecast/shell/common/cast_content_client.cc
index a09ec454a2..65d50ec079 100644
--- a/chromecast/shell/common/cast_content_client.cc
+++ b/chromecast/shell/common/cast_content_client.cc
@@ -4,6 +4,7 @@
#include "chromecast/shell/common/cast_content_client.h"
+#include "chromecast/common/version.h"
#include "content/public/common/user_agent.h"
#include "ui/base/l10n/l10n_util.h"
#include "ui/base/resource/resource_bundle.h"
@@ -11,13 +12,9 @@
namespace chromecast {
namespace shell {
-// TODO(lcwu): http://crbug.com/391080. Create the actual Chromecast
-// product version string and hook it up here.
-#define PRODUCT_VERSION "0.0.0.0"
-
std::string GetUserAgent() {
std::string product = "Chrome/" PRODUCT_VERSION;
- return content::BuildUserAgentFromProduct(product);
+ return content::BuildUserAgentFromProduct(product) + " CrKey";
}
CastContentClient::~CastContentClient() {
diff --git a/chromecast/shell/browser/url_request_context_factory.cc b/chromecast/shell/browser/url_request_context_factory.cc
index a1db712311..03b5d9ddf6 100644
--- a/chromecast/shell/browser/url_request_context_factory.cc
+++ b/chromecast/shell/browser/url_request_context_factory.cc
@@ -26,8 +26,8 @@
#include "net/ocsp/nss_ocsp.h"
#include "net/proxy/proxy_service.h"
#include "net/socket/next_proto.h"
-#include "net/ssl/default_server_bound_cert_store.h"
-#include "net/ssl/server_bound_cert_service.h"
+#include "net/ssl/channel_id_service.h"
+#include "net/ssl/default_channel_id_store.h"
#include "net/ssl/ssl_config_service_defaults.h"
#include "net/url_request/data_protocol_handler.h"
#include "net/url_request/url_request_context.h"
@@ -184,11 +184,11 @@ void URLRequestContextFactory::InitializeSystemContextDependencies() {
host_resolver_ = net::HostResolver::CreateDefaultResolver(NULL);
// TODO(lcwu): http://crbug.com/392352. For performance and security reasons,
- // a persistent (on-disk) HttpServerProperties and ServerBoundCertService
- // might be desirable in the future.
- server_bound_cert_service_.reset(new net::ServerBoundCertService(
- new net::DefaultServerBoundCertStore(NULL),
- base::WorkerPool::GetTaskRunner(true)));
+ // a persistent (on-disk) HttpServerProperties and ChannelIDService might be
+ // desirable in the future.
+ channel_id_service_.reset(
+ new net::ChannelIDService(new net::DefaultChannelIDStore(NULL),
+ base::WorkerPool::GetTaskRunner(true)));
cert_verifier_.reset(net::CertVerifier::CreateDefault());
@@ -267,7 +267,7 @@ void URLRequestContextFactory::PopulateNetworkSessionParams(
net::HttpNetworkSession::Params* params) {
params->host_resolver = host_resolver_.get();
params->cert_verifier = cert_verifier_.get();
- params->server_bound_cert_service = server_bound_cert_service_.get();
+ params->channel_id_service = channel_id_service_.get();
params->ssl_config_service = ssl_config_service_.get();
params->transport_security_state = transport_security_state_.get();
params->http_auth_handler_factory = http_auth_handler_factory_.get();
@@ -291,8 +291,7 @@ net::URLRequestContext* URLRequestContextFactory::CreateSystemRequestContext() {
net::URLRequestContext* system_context = new net::URLRequestContext();
system_context->set_host_resolver(host_resolver_.get());
- system_context->set_server_bound_cert_service(
- server_bound_cert_service_.get());
+ system_context->set_channel_id_service(channel_id_service_.get());
system_context->set_cert_verifier(cert_verifier_.get());
system_context->set_proxy_service(proxy_service_.get());
system_context->set_ssl_config_service(ssl_config_service_.get());
@@ -364,8 +363,7 @@ net::URLRequestContext* URLRequestContextFactory::CreateMainRequestContext(
net::URLRequestContext* main_context = new net::URLRequestContext();
main_context->set_host_resolver(host_resolver_.get());
- main_context->set_server_bound_cert_service(
- server_bound_cert_service_.get());
+ main_context->set_channel_id_service(channel_id_service_.get());
main_context->set_cert_verifier(cert_verifier_.get());
main_context->set_proxy_service(proxy_service_.get());
main_context->set_ssl_config_service(ssl_config_service_.get());